from taibun.taibun import Converter
from utils import checker

c = Converter(system="Zhuyin", punctuation='none')
c_north = Converter(system="Zhuyin", dialect="north", punctuation='none')

def test_zhuyin_initials():
    bilabial = ["啡,ㄅㄧ","波,ㄆㄜ","毛,ㄇㆦˊ","猫,ㆠㄚˊ"]
    checker(bilabial, c, c_north)
    alveolar = ["地,ㄉㆤ˫/ㄉㄨㆤ˫","唾,ㄊㄜ˪","早,ㄗㄚˋ","厝,ㄘㄨ˪","思,ㄙㄨ","耐,ㄋㄞ˫","如,ㆡㄨˊ/ㄌㄨˊ","柳,ㄌㄧㄨˋ"]
    checker(alveolar, c, c_north)
    alveolo_palatal = ["遮,ㄐㄧㄚ","手,ㄑㄧㄨˋ","寫,ㄒㄧㄚˋ","而,ㆢㄧˊ/ㄌㄧˊ"]
    checker(alveolo_palatal, c, c_north)
    velar = ["求,ㄍㄧㄨˊ","去,ㄎㄧ˪","雅,ㄫㄚˋ","語,ㆣㄧˋ/ㆣㄨˋ","喜,ㄏㄧˋ"]
    checker(velar, c, c_north)

def test_zhuyin_vowels_and_rhymes():
    front = ["衣,ㄧ","會,ㆤ˫","圓,ㆪˊ","楹,ㆥˊ"]
    checker(front, c, c_north)
    central = ["阿,ㄜ","亞,ㄚ","餡,ㆩ˫"]
    checker(central, c, c_north)
    back = ["禹,ㄨˋ","烏,ㆦ","張,ㄉㄧㆫ","唔,ㆧ"]
    checker(back, c, c_north)

def test_zhuyin_finals():
    nasal = ["音,ㄧㆬ","寅,ㄧㄣˊ","紅,ㄤˊ"]
    checker(nasal, c, c_north)
    stop = ["葉,ㄧㄚㆴ˙","楬,ㄚㆵ","惡,ㆦㆶ","曷,ㄚㆷ˙"]
    checker(stop, c, c_north)
    syllabic = ["姆,ㆬˋ","黃,ㆭˊ"]
    checker(syllabic, c, c_north)

def test_zhuyin_syllables_additional():
    additional = ["㨻,ㄗㆩ˫","一概,ㄧㆵ ㄎㄞ˪","三層,ㄙㆰ ㄗㄢ˪","不屑,ㄅㄨㆵ ㄙㄨㆵ","丑,ㄊㄧㄨˋ","丼,ㄉㆱˊ","乎,ㄏㆧ","乞食,ㄎㄧㆵ ㄐㄧㄚㆷ˙","亂鐘,ㄌㄨㄢ˫ ㄐㄧㄥ","交落,ㄍㄚ ㄌㄠㆷ˙","人間,ㆢㄧㄣˊ ㄍㄢ/ㄌㄧㄣˊ ㄍㄢ","仰角,ㆣㄧㆲˋ ㄍㄚㆶ","休克,ㄏㄧㄨ ㄎㄧㆶ","侮辱,ㆠㄨˋ ㆢㄧㆦㆶ˙/ㆠㄨˋ ㄌㄧㆦㆶ˙","停電,ㄊㄧㄥˊ ㄉㄧㄢ˫","偝,ㆮ˫/ㄧㄤ˫","傳接,ㄊㄨㄢˊ ㄐㄧㄚㆴ","僥倖,ㄏㄧㄠ ㄏㄧㄥ˫","儼硬,ㆣㄧㆰˋ ㄫㆤ˫/ㆣㄧㆰˋ ㄫㄧ˫","兄哥,ㄏㄧㆩ ㄍㄜ","充作,ㄑㄧㆲ ㄗㆦㆶ","免費,ㆠㄧㄢˋ ㄏㄨㄧ˪","入口,ㆢㄧㆴ˙ ㄎㄠˋ/ㄌㄧㆴ˙ ㄎㄠˋ","八仙,ㄅㄚㆵ ㄒㄧㄢ","八月節,ㄅㆤㆷ ㆣㄨㆤㆷ˙ ㄗㆤㆷ/ㄅㄨㆤㆷ ㆣㆤㆷ˙ ㄗㄨㆤㆷ","冇浡,ㄆㆩ˪ ㄆㄨㆷ˙","冰雹,ㄅㄧㄥ ㄆㄠㆷ˙","刐,ㄉㆮˋ","判斷,ㄆㄨㆩ˪ ㄉㄨㄢ˪","別莊,ㄅㄧㄚㆵ˙ ㄗㆲ","刮,ㄍㄨㆤㆷ/ㄍㄨㄧㆷ","剔斥,ㄊㄚㆶ ㄊㄧㆶ","割禮,ㄍㄚㆵ ㄌㆤˋ","劃,ㄨㆤㆷ˙/ㄨㄧㆷ˙","加快,ㄍㄚ ㄎㄨㄞ˪","劣,ㄌㄨㄚㆵ˙","劫棺,ㄍㄧㄚㆴ ㄍㄨㄢ","匆促,ㄘㆲ ㄑㄧㆦㆶ","匹敵,ㄆㄧㆵ ㄉㄧㆶ˙","半遂,ㄅㄨㄢ˪ ㄙㄨㄧ˫","協和,ㄏㄧㄚㆴ˙ ㄏㄜˊ","卡片,ㄎㄚㆷ ㄆㆪ˪","卯名,ㆠㄠˋ ㄇㄧㄚˊ","卯落去,ㄇㄠㆷ ㄌㄜㆷ˙ ㄎㄧ˪","危險,ㆣㄨㄧˊ ㄏㄧㆰˋ","卵包,ㄋㆭ˫ ㄅㄠ","參照,ㄘㆰ ㄐㄧㄠ˪","合歡,ㄏㄚㆴ˙ ㄏㄨㄢ","含蓄,ㄏㆰˊ ㄊㄧㆦㆶ","吭,ㄎㆭㆷ","吸汗,ㄎㄧㆴ ㄍㄨㆩ˫","吻笑,ㆠㄨㄣˋ ㄑㄧㄜ˪","呃酸,ㆤㆷ ㄙㆭ","呿,ㄎㄨㆷ","品嘗,ㄆㄧㄣˋ ㄒㄧㆲˊ","哈啾,ㄏㄚㆷ ㄑㄧㆫ˪","哈氣,ㄏㄚ ㄎㄨㄧ˪","哼呻,ㄏㆮ ㄘㄢ","唉,ㄏㄞㆷ","喀,ㄎㆥㆷ˙","喃,ㄋㄠㆷ","喓,ㄧㆯ","喔,ㆦ","喝令,ㄏㄨㄚㆷ ㄌㄧㄥ˫","喢,ㄙㆩㆷ","嗙,ㄆㆭㆷ","嗾,ㄗㄚㆶ˙","嘈嘈唸,ㄘㄠㆷ˙ ㄘㄠㆷ˙ ㄌㄧㆰ˫","嘐潲,ㄏㄠ ㄒㄧㄠˊ","噎,ㄨㆷ","噯,ㄞㆷ","噷,ㄏㆬㆷ˙","嚇驚,ㄏㆤㆷ ㄍㄧㆩ","嚓,ㄑㄧㄚㆶ˙","嚷,ㆢㄧㄤˋ/ㄌㄧㆲˋ","嚾,ㄨㄤ","囤糴,ㄉㄨㄣˋ ㄉㄧㄚㆷ˙","困局,ㄎㄨㄣ˪ ㄍㄧㆦㆶ˙","圓參,ㆪˊ ㄙㆱ","在,ㄗㄞ˫","坉塗,ㄊㄨㄣ˫ ㄊㆦˊ","坑谷,ㄎㆥ ㄍㆦㆶ/ㄎㆪ ㄍㆦㆶ","坱埃,ㄧㄥ ㄧㄚ","垃圾,ㄌㄚㆷ ㄙㄚㆴ","基金,ㄍㄧ ㄍㄧㆬ","堯韭,ㆣㄧㄠˊ ㄍㄨˋ","塌替,ㄊㄚㆴ ㄊㆤ˪/ㄊㄚㆴ ㄊㄨㆤ˪","壁畫,ㄅㄧㄚㆷ ㄨㆤ˫","壓模,ㄚㆴ ㆠㆦˊ","外甥,ㆣㄨㆤ˫ ㄒㄧㄥ","大山,ㄉㄨㄚ˫ ㄙㄨㆩ","天光,ㄊㆪ ㄍㆭ","天后,ㄊㄧㄢ ㄏㄧㄜ˫","太魯閣,ㄊㄞ˪ ㄌㆦˋ ㄍㄜㆷ","央及,ㄧㄤ ㄍㄧㆴ˙","奇雙,ㄎㄧㄚ ㄒㄧㄤ","奔喪,ㄆㄨㄣ ㄙㆲ","好客,ㄏㆧ˪ ㄎㆤㆷ","妙,ㄇㄧㄠ˫","妝娗,ㄗㆭ ㄊㆩ˫","妾,ㄑㄧㄚㆴ","姓,ㄙㆥ˪/ㄒㆪ˪","媽媽,ㄇㄚ ㄇㄚ","孵,ㄅㄨ˫","學園,ㄏㄚㆶ˙ ㄏㆭˊ","學歹,ㄜㆷ˙ ㄆㆮˋ","孽,ㆣㄧㄚㆵ˙","宅,ㄊㆤㆷ˙","安眠,ㄢ ㆠㄧㄣˊ","寄來,ㄍㄧㄚ˪ ㄌㄞˊ","密實,ㆠㄚㆵ˙ ㄗㄚㆵ˙","專員,ㄗㄨㄢ ㄨㄢˊ","尿鈷,ㆢㄧㄜ˫ ㄍㆦˋ/ㄌㄧㄜ˫ ㄍㆦˋ","屁,ㄆㄨㄧ˪","屆時,ㄍㄞ˪ ㄒㄧˊ","屈橋,ㄎㄨㆵ ㄍㄧㄜˊ","屏遮那,ㄏㆤ˪ ㄙㆤㄣ ㄋㄚˋ","屐,ㄍㄧㄚㆷ˙","岩鹽,ㆣㆰˊ ㄧㆰˊ","岳父,ㆣㄚㆶ˙ ㄏㄨ˫","年表,ㄋㄧˊ ㄅㄧㄜˋ","店租,ㄉㄧㆰ˪ ㄗㆦ","庵廟,ㆰ ㆠㄧㄜ˫","廿,ㆢㄧㄚㆴ˙/ㄌㄧㄚㆴ˙","彪,ㄅㄧㄨ","彼樣,ㄏㄧㆵ ㄧㆫ˫","徼,ㄎㄧㄜ˪","忍心,ㆢㄧㆬˋ ㄒㄧㆬ/ㄌㄧㆬˋ ㄒㄧㆬ","快活,ㄎㄨㆪ˪ ㄨㄚㆷ˙","忽然,ㄏㄨㆵ ㆢㄧㄢˊ/ㄏㄨㆵ ㄌㄧㄢˊ","怦,ㄆㆥ˫","怯膽,ㄎㄧㄚㆴ ㄉㆩˋ","恐畏,ㄎㄧㆲˋ ㄨㄧ˪","惜略,ㄒㄧㄜㆷ ㄌㄧㄜㆷ˙","愕,ㆣㆦㆶ˙","愣,ㆣㄤ˫","慼心,ㄘㆤㆷ ㄒㄧㆬ/ㄘㄨㆤㆷ ㄒㄧㆬ","憚,ㄉㄢ˫","懦,ㄋㆦ˫","懷念,ㄏㄨㄞˊ ㄌㄧㆰ˫","戇,ㆣㆲ˫","扒飯,ㄅㆤ ㄅㆭ˫","扭尻川,ㄫㄧㄨˋ ㄎㄚ ㄘㆭ","抓癢,ㆢㄧㄠ˪ ㄐㄧㆫ˫/ㄌㄧㄠ˪ ㄐㄧㆫ˫","披埕,ㄆㄧ ㄉㄧㆩˊ","抹粉,ㆠㄨㄚㆷ ㄏㄨㄣˋ","抾拾,ㄎㄧㄜㆷ ㄒㄧㆴ˙","拆壇,ㄊㄧㄚㆷ ㄉㄨㆩˊ","拋出,ㄆㄠ ㄘㄨㆵ","拋捎,ㄆㄚ ㄙㄚ","拍插,ㄆㄚㆷ ㄘㄚㆴ","拖直,ㄊㄨㄚ ㄉㄧㆵ˙","招倚,ㄐㄧㄜ ㄨㄚˋ","括流,ㄍㄨㄚㆷ ㄌㄠˊ","指,ㄗㆮˋ","挓,ㄊㄚ˪","挕捒,ㄏㆪ˪ ㄙㄚㆶ","挨餓,ㄞ ㆣㄜ˫","掀冊,ㄏㄧㄢ ㄘㆤㆷ","掃蕩,ㄙㄠ˪ ㄉㆲ˫","掇,ㄉㄨㄚㆷ","掙,ㄐㄧㆩ˫","掩目雞,ㆱ ㆠㄚㆶ˙ ㄍㆤ/ㆱ ㆠㄚㆶ˙ ㄍㄨㆤ","插春,ㄘㄚㆷ ㄘㄨㄣ","揬,ㄉㄨㆷ˙","搐,ㄉㄧㄨㆷ","搭嚇,ㄉㄚㆷ ㄏㄧㆩㆷ","搭里霧,ㄉㄚ˫ ㄌㄧˋ ㆠㄨㆷ","摳,ㄎㆯㆷ˙","撇清,ㄆㄧㄚㆵ ㄑㄧㄥ","撓,ㄫㄧㄠˋ","撤職,ㄊㄧㄚㆵ ㄐㄧㆵ","擉,ㄉㄧㄚㆶ˙","擔當,ㄉㆰ ㄉㆭ","擗,ㄆㄧㄚㆶ˙","攀登,ㄆㄢ ㄉㄧㄥ","攔閘,ㄋㄨㄚˊ ㄗㄚㆷ˙","敱,ㄎㆮˋ","斟酒,ㄊㄧㄣˊ ㄐㄧㄨˋ","方興未艾,ㄏㆲ ㄏㄧㄥ ㆠㄧ˫ ㄫㄞ˫","昨,ㄗㄜㆷ˙","晚會,ㆠㄨㄢˋ ㄏㄨㆤ˫","晴,ㄗㆥˊ","晾,ㄋㆤˊ","曲線,ㄎㄧㆦㆶ ㄙㄨㆩ˪","朗讀,ㄌㆲˋ ㄊㆦㆶ˙","木業,ㆠㆦㆶ˙ ㆣㄧㄚㆴ˙","末路,ㆠㄨㄚㆵ˙ ㄌㆦ˫","杵,ㄊㄨˋ","枴,ㄍㄨㄞˋ","染,ㆢㄧㆰˋ/ㄌㄧㆰˋ","校閱,ㄍㄠ˪ ㄨㄚㆵ˙","核可,ㄏㄧㆶ˙ ㄎㄜˋ","桌屜,ㄉㄜㆷ ㄊㄨㄚㆷ","榆,ㆢㄧㄨˊ/ㄌㄧㄨˊ","標本,ㄅㄧㄠ ㄅㄨㄣˋ","樸實,ㄆㄜㆷ ㄒㄧㆵ˙","橫扴,ㄏㄨㆮˊ ㄍㆤㆷ˙/ㄏㄨㆪˊ ㄍㆤㆷ˙","檨,ㄙㄨㆮ˫","欶,ㄙㄨㆷ","歇影,ㄏㄧㄜㆷ ㄧㆩˋ","歌譜,ㄍㄨㄚ ㄆㆦˋ","歡度,ㄏㄨㆩ ㄉㆦ˫","歪斜,ㄨㄞ ㄘㄨㄚㆷ˙","每擺,ㄇㄨㄧˋ ㄅㄞˋ","沃雨,ㄚㆶ ㄏㆦ˫","沉著,ㄉㄧㆬˊ ㄉㄧㆦㆶ˙","沒藥,ㆠㄨㆵ˙ ㄧㄜㆷ˙","沓,ㄉㄠㆷ˙","沓滴,ㄉㄚㆴ˙ ㄉㄧㆷ","沖水,ㄑㄧㄤˊ ㄗㄨㄧˋ","沫,ㄆㄨㆤㆷ˙/ㄆㆤㆷ˙","海蟹,ㄏㄞˋ ㄏㆤ˫","涼腔,ㄌㄧㄤˊ ㄎㄧㄤ","添設,ㄊㄧㆰ ㄒㄧㄚㆵ","渺茫,ㆠㄧㄠˋ ㆠㆲˊ","湠叢,ㄊㄨㆩ˪ ㄗㄤˊ","滅無,ㆠㄧㄚㆵ˙ ㆠㄜˊ","漂浮,ㄆㄧㄠ ㄆㄨˊ","漉屎,ㄌㆦㆶ ㄙㄞˋ","漚肥,ㄠ ㄅㄨㄧˊ","漳,ㄐㄧㄤ","潑扇,ㄆㄨㄚㆷ ㄒㆪ˪","潑賤,ㄆㄨㄚㆵ ㄐㄧㄢ˫","潤餅,ㆡㄨㄣ˫ ㄅㄧㆩˋ/ㄌㄨㄣ˫ ㄅㄧㆩˋ","澩,ㄏㆯㆷ˙","激力,ㄍㄧㆶ ㄌㄚㆵ˙","濺,ㄗㄨㆩ˫","煏,ㄅㄧㄚㆶ","煠,ㄙㄚㆷ˙","煤,ㄇㄨㆤˊ","熁,ㄏㆩㆷ","熊,ㄏㄧㆬˊ","熱烈,ㆢㄧㄚㆵ˙ ㄌㄧㄚㆵ˙/ㄌㄧㄚㆵ˙ ㄌㄧㄚㆵ˙","爁,ㄋㄚㆷ","爹,ㄉㄧㄚ","牚,ㄊㆥ˪","牛膝,ㆣㄧㄨˊ ㄑㄧㆶ","物,ㄇㄧㆷ˙/ㄇㆭㆷ˙","物代,ㄇㄧㆷ ㄉㄞ˫","牽強,ㄎㄧㄢ ㄍㄧㆲˊ","牽磕,ㄎㄢ ㄎㄚㆴ˙","猛勇,ㆠㄧㄥˋ ㄧㆲˋ","玉環,ㆣㄧㆶ˙ ㄎㄨㄢˊ","玉蘭,ㆣㄧㄜㆶ˙ ㄌㄢˊ","玩具,ㆣㄨㄢˋ ㄎㄨ˫","甘苦,ㄍㆰ ㄎㆦˋ","甪毛,ㄌㄨㆵ ㄇㆭˊ","番薯,ㄏㄢ ㄐㄧˊ/ㄏㄢ ㄗㄨˊ","疊尖,ㄊㄧㄚㆴ˙ ㄐㄧㆰ","疏散,ㄙㆦ ㄙㄢ˪","癮甲,ㆣㄧㄢ˪ ㄍㄚㆷ","百般,ㄅㄚㆷ ㄅㄨㆩ","益蟲,ㄧㆶ ㄊㄧㆲˊ","益閣,ㄧㄚㆷ ㄍㄜㆷ","監牢,ㄍㆩ ㄌㄜˊ","相閃,ㄒㄧㄜ ㄒㄧㆰˋ","眉額,ㆠㄞˊ ㄏㄧㄚㆷ˙","看,ㄎㄨㆩ˪","眩痧,ㄏㄧㄣˊ ㄙㄨㄚ","眵,ㄘㄨㆷ","眼福,ㆣㄢˋ ㄏㆦㆶ","睚,ㄍㆮˊ","督察,ㄉㆦㆶ ㄘㄚㆵ","瞌,ㄎㆤㆷ/ㄎㄨㆤㆷ","砌,ㄍㄧㆷ","研缽,ㆣㄧㄥˋ ㄅㄨㄚㆷ","破缺,ㄆㄨㄚ˪ ㄎㄧㆷ","硩,ㄉㆤㆷ","碗頭箸尾,ㄨㆩˋ ㄊㄠˊ ㄉㄧ˫ ㆠㄨㆤˋ/ㄨㆩˋ ㄊㄠˊ ㄉㄨ˫ ㆠㆤˋ","碧潭,ㄆㄧㆶ ㄊㆰˊ","確保,ㄎㄚㆶ ㄅㄜˋ","磨坩,ㆠㄨㄚˊ ㄎㆩ","礁石,ㄉㄚ ㄐㄧㄜㆷ˙","礎,ㄘㆦˋ","礙著,ㆣㄞ˫ ㄉㄧㄜㆷ˙","票箱,ㄆㄧㄜ˪ ㄒㄧㆫ","禿,ㄊㄨㆵ","空空,ㄎㄤ ㄎㄤ","突,ㄉㄨㆵ˙","笠,ㄌㆤㆷ˙","筆算,ㄅㄧㆵ ㄙㄨㄢ˪","簇,ㄘㆦㆶ","簸,ㄅㄨㄚ˪","籤王,ㄑㄧㆰ ㆲˊ","粒,ㄌㄧㄚㆴ˙","糠瘡,ㄎㆭ ㄘㆭ","糶,ㄊㄧㄜ˪","紂,ㄉㄧㄨ˫","納采,ㄌㄚㆴ˙ ㄘㄞˋ","索梯,ㄙㄜㆷ ㄊㄨㄧ","累積,ㄌㄨㄧˋ ㄐㄧㆶ","紺,ㄎㆲˋ","結疤,ㄍㄧㄚㆵ ㄅㄚ","絕對,ㄗㄨㄚㆵ˙ ㄉㄨㄧ˪","絨布,ㆢㄧㆲˊ ㄅㆦ˪/ㄌㄧㆲˊ ㄅㆦ˪","經繭,ㄍㆥ ㄍㄧㄢˋ/ㄍㆪ ㄍㄧㄢˋ","綠色,ㄌㄧㆶ˙ ㄒㄧㆶ","緝捕,ㄑㄧㆴ ㄅㆦˋ","緟,ㄊㆲ˫","編篡,ㄅㄧㄢ ㄘㄨㄢ˪","缺糧,ㄎㄨㄚㆵ ㄋㄧㄨˊ","美味,ㆠㄧˋ ㆠㄧ˫","翕熱,ㄏㄧㆴ ㆡㄨㄚㆷ˙/ㄏㄧㆴ ㄌㄨㄚㆷ˙","聘請,ㄆㄧㄥ˪ ㄑㄧㆩˋ","聽錯,ㄊㄧㆩ ㄘㄜ˪","肉目,ㆠㄚㆷ ㆠㄚㆶ˙","脈搏,ㄇㆤㆷ˙ ㄆㆦㆶ","脫節,ㄊㄨㄚㆵ ㄐㄧㄚㆵ","腔調,ㄎㄧㆫ ㄉㄧㄠ˫","腰骨,ㄧㄜ ㄍㄨㆵ","腳錢,ㄍㄧㄜㆷ ㄐㆪˊ","船運,ㄗㄨㄣˊ ㄨㄣ˫","色牙,ㄒㄧㆶ ㆣㄚˊ","茅草,ㄇㄠˊ ㄘㄠˋ","草笠仔,ㄘㄠˋ ㄌㆤㆷ˙ ㄚˋ/ㄘㄠˋ ㄌㄨㆤㆷ˙ ㄚˋ","莢,ㄫㆤㆷ","落落,ㄌㄚㆶ ㄌㄜㆷ˙","蓆,ㄑㄧㄜㆷ˙","蔥藕,ㄘㄤ ㄫㄠ˫","蕨貓,ㄍㄨㆤㆷ ㄋㄧㄠ","薄待,ㄅㆦㆶ˙ ㄊㄞ˫","薄膜,ㄅㄜㆷ˙ ㄇㆦㆷ˙","薑,ㄍㄧㆫ","藃,ㄏㄧㄠㆷ","藩屏,ㄆㄨㄢ ㄅㄧㄣˊ","虹,ㄎㄧㄥ˫","蚻,ㄗㄨㄚㆷ˙","蛤蜊,ㄍㄚㆴ ㄌㄚˊ","蜀七,ㄒㄧㆦㆶ˙ ㄑㄧㆵ","蜈蚣,ㆣㄧㄚˊ ㄍㄤ","蜜月,ㆠㄧㆵ˙ ㆣㄨㄚㆵ˙","蝕秤,ㄒㄧㆷ˙ ㄑㄧㄣ˪","蝛,ㆠㄨㄧ","蝨,ㄙㄚㆵ","蟯桮,ㆣㄧㄜˊ ㄅㄨㆤ","蟯蟯動,ㄫㄧㄠㆷ˙ ㄫㄧㄠㆷ˙ ㄉㄤ˫","蟳,ㄐㄧㆬˊ","蟶坪,ㄊㄢ ㄆㄧㆩˊ","蠓罩,ㆠㄤˋ ㄉㄠ˪","蠘,ㄑㄧㆷ˙","蠻皮病,ㆠㄢˊ ㄆㄨㆤˊ ㄅㆥ˫/ㆠㄢˊ ㄆㆤˊ ㄅㆪ˫","血油,ㄏㄨㆤㆷ ㄧㄨˊ/ㄏㄨㄧㆷ ㄧㄨˊ","血緣,ㄏㄧㄚㆵ ㄧㄢˊ","裂縫,ㄌㄧㆷ˙ ㄆㄤ˫","裂隙,ㄌㄧㄚㆷ ㄎㄧㄚㆷ","褪,ㄊㆭ˪","褫奪,ㄊㄧˋ ㄉㄨㄚㆵ˙","襟章,ㄎㄧㆬ ㄐㄧㆲ","襪束,ㆠㄨㆤㆷ˙ ㄙㆦㆶ","規暝,ㄍㄨㄧ ㄇㆤˊ/ㄍㄨㄧ ㄇㄧˊ","覕喙,ㆠㄧㆷ ㄘㄨㄧ˪","觸纏,ㄉㄚㆶ ㄉㆪˊ","訣說,ㄍㄨㄚㆵ ㄙㄨㄚㆵ","詰舌,ㄎㄧㄚㆵ ㄐㄧㆷ˙","誇張,ㄎㄨㄚ ㄉㄧㆲ","諜,ㄉㄧㄚㆴ˙","謔削,ㆣㄧㄜㆷ˙ ㄒㄧㄚㆷ","謗大,ㄅㆲ˪ ㄉㄨㄚ˫","謙遜,ㄎㄧㆰ ㄙㄨㄣ˪","謬誤,ㆠㄧㄨ˫ ㆣㆦ˫","謼,ㄏㆦㆷ","豐沛,ㄆㆲ ㄆㄞ˪","買囑,ㄇㄞˋ ㄐㄧㆦㆶ","賴,ㄌㄨㄚ˫","赤疹,ㄑㄧㄚㆷ ㄐㄧㄣˋ","超市,ㄑㄧㄠ ㄑㄧ˫","趖,ㄙㄜˊ","跋涉,ㄅㄨㄚㆵ˙ ㄒㄧㄚㆴ˙","跡,ㆢㄧㄚㆷ/ㄌㄧㄚㆷ","跤曲,ㄎㄚ ㄎㄧㄠ","跩,ㄗㄨㆮ˫","跳躂,ㄊㄧㄠ˪ ㄊㄚㆵ","躄倒,ㄆㄧㆷ ㄉㄜˋ","躡,ㄋㆤㆷ/ㄋㄧㆷ","輕聲細說,ㄎㄧㄣ ㄒㄧㆩ ㄙㆤ˪ ㄙㄨㆤㆷ/ㄎㄧㄣ ㄒㄧㆩ ㄙㄨㆤ˪ ㄙㆤㆷ","轄境,ㄏㄚㆵ ㄍㄧㄥˋ","辟走,ㄆㄧㄚㆷ ㄗㄠˋ","迎神,ㄫㄧㄚˊ ㄒㄧㄣˊ","迒,ㄏㆩ˫","迫切,ㄅㄧㆶ ㄑㄧㄚㆵ","迭,ㄉㄧㄚㆵ˙","迸,ㄅㄧㄤ˪","送達,ㄙㄤ˪ ㄉㄚㆵ˙","逝,ㄗㄨㄚ˫","遮勘,ㆢㄧㄚ ㄎㆰ˪/ㄌㄧㄚ ㄎㆰ˪","邀約,ㄧㄠ ㄧㆦㆶ","邑,ㄧㆴ","那通,ㄋㄚˋ ㄊㄤ","郁,ㄏㄧㆦㆶ","鄭,ㄉㆥ˫","酷人,ㄎㆦㆶ ㄌㄤˊ","重青,ㄉㄤ˫ ㄘㆥ/ㄉㄤ˫ ㄑㆪ","釣艚,ㄉㄧㄜ˪ ㄗㄜˊ","銀髮,ㆣㄧㄣˊ ㄏㄨㄚㆵ/ㆣㄨㄣˊ ㄏㄨㄚㆵ","銳減,ㆡㄨㆤ˫ ㄍㄧㆰˋ/ㄌㄨㆤ˫ ㄍㄧㆰˋ","錚,ㄘㆩ˫","錦繡,ㆣㄧㆬˋ ㄒㄧㄨ˪","鎮煞,ㄉㄧㄣ˪ ㄙㄨㄚㆷ","鏨,ㄗㆰ˫","鐵塔,ㄊㄧㆷ ㄊㄚㆷ","鑠,ㄒㄧㄚㆶ","鑱,ㄑㄧㆬˊ","鑿,ㄘㄚㆶ˙","閂,ㄘㄨㆩ˪","閱覽,ㄧㄚㆵ˙ ㄌㆰˋ","闊腹,ㄎㄨㄚㆷ ㄅㄚㆶ","闖,ㄘㄨㄤ˪","關車,ㄍㄨㆮ ㄑㄧㄚ/ㄍㄨㆪ ㄑㄧㄚ","闡,ㄑㄧㄢˋ","阿沙不魯,ㄚ ㄙㄚ ㄅㄨㆷ ㄌㄨㆷ","陷,ㄏㆰ˫","雜柴,ㄗㄚㆴ˙ ㄘㄚˊ","雞齊根,ㄍㆤ ㄗㆤˊ ㄍㄧㄣ/ㄍㄨㆤ ㄗㄨㆤˊ ㄍㄨㄣ","靴管,ㄏㄧㄚ ㄍㆲˋ","項,ㄏㄤ˫","領班,ㄋㄧㄚˋ ㄅㄢ","額外,ㆣㄧㄚㆷ˙ ㆣㄨㄚ˫","風吹日曝,ㄏㆲ ㄘㄨㆤ ㆢㄧㆵ˙ ㄆㄚㆶ˙/ㄏㆲ ㄘㆤ ㄌㄧㆵ˙ ㄆㄚㆶ˙","香,ㄏㄧㆫ","香茅,ㄏㄧㄤ ㄏㆬˊ","香華,ㄏㄧㆲ ㄏㄨㄚ","騙,ㄆㄧㄢ˪","驕傲,ㄍㄧㄠ ㄫㆦ˫","鬧房,ㄋㄠ˫ ㄅㄤˊ","鬱卒,ㄨㆵ ㄗㄨㆵ","魠,ㄊㄜㆷ","鱉,ㄅㄧㆷ","鴆,ㄊㄧㆬ","鶴,ㄏㄜㆷ˙","麥牙,ㆠㆤㆷ˙ ㆣㆤˊ","麻衫,ㄇㄨㄚˊ ㄙㆩ","默契,ㆠㄧㆶ˙ ㄎㆤ˪/ㆠㄧㆶ˙ ㄎㄨㆤ˪","黜,ㄊㄨㆷ","齴,ㆣㄧㄤ˪","龐,ㄆㄧㄤ˫","𠢕,ㆣㄠˊ","𠯗,ㄐㄧㆴ˙","𣁳,ㄎㄚㆵ","𤆬,ㄘㄨㄚ˫","𧮙,ㄘㄜㆷ","𧿳,ㄆㄨㆵ˙","𨂿,ㄨㆮˋ","𩚨,ㄎㄧㄨ˫","𩛩,ㄍㄠㆷ"]
    checker(additional, c, c_north)